Learn R Programming

mclm (version 0.2.7)

chisq1_to_p: Proportion of chi-squared distribution with one degree of freedom that sits to the right of x

Description

Helper function that takes as its argument a numerical value x and that returns the proportion p of the chi-squared distribution with one degree of freedom that sits to the right of the value `x.

Usage

chisq1_to_p(x)

Value

The proportion p of the chi-squared distribution with one degree of freedom that sits to the right of the value x.

Arguments

x

A number.

See Also

p_to_chisq1()