Learn R Programming

mclm (version 0.2.7)

p_to_chisq1: P right quantile in chi-squared distribution with 1 degree of freedom

Description

P right quantile that takes as its argument a probability p and that returns the p right quantile in the \(\chi^2\) distribution with one degree of freedom. In other words, it returns a value q such that a proportion p \(\chi^2\) distribution with one degree of freedom lies above q.

Usage

p_to_chisq1(p)

Value

The p

right quantile in the \(\chi^2\) distribution with one degree of freedom.

Arguments

p

A proportion.

See Also

chisq1_to_p()