This function prints a concordance in KWIC format.
print_kwic(
x,
min_c_left = NA,
max_c_left = NA,
min_c_match = NA,
max_c_match = NA,
min_c_right = NA,
max_c_right = NA,
from = 1,
n = 30,
drop_tags = TRUE
)Invisibly, x.
An object of class conc.
Minimum and maximum size, expressed in number of characters, of the left co-text in the KWIC display.
Minimum and maximum size, expressed in number of characters, of the match in the KWIC display.
Minimum and maximum size, expressed in number of characters, of the right co-text in the KWIC display.
Index of the first item of x to be displayed.
Number of consecutive items in x to be displayed.
Logical. Should tags be hidden?