Learn R Programming

mclm (version 0.2.7)

short_names: Shorten filenames

Description

Helper functions that make the paths to a file shorter.

Usage

drop_path(x, ...)

drop_extension(x, ...)

short_names(x, ...)

Value

An object of the same class as x.

Arguments

x

An object of class fnames or a character vector.

...

Additional arguments.

Functions

  • drop_path(): Extract the base name of a path, removing the paths leading to it.

  • drop_extension(): Remove extension from a filename.

  • short_names(): Remove both paths leading to a file and its extension.

Examples

Run this code
cwd_fnames <- as_fnames(c("folder/file1.txt", "folder/file2.txt", "folder/file3.txt"))
drop_path(cwd_fnames)
drop_extension(cwd_fnames)
short_names(cwd_fnames) # same as drop_path(drop_extension(cwd_fnames))

Run the code above in your browser using DataLab