P right quantile that takes as its argument a probability p and that returns
the p right quantile in the \(\chi^2\) distribution with one degree of
freedom. In other words, it returns a value q such that a proportion p
\(\chi^2\) distribution with one degree of freedom lies above q.
p_to_chisq1(p)The p
right quantile in the \(\chi^2\) distribution with one degree of freedom.
A proportion.
chisq1_to_p()